==> igniteui-react-layouts-18.6.1.tgz: package/esm2015/lib/TooltipTextPresenter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, INotifyPropertyChanged_$type, PropertyChangedEventArgs, markType } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { DeviceUtils } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { Size } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let TooltipTextPresenter = /*@__PURE__*/ (() => {
    class TooltipTextPresenter extends Base {
        get e() {
            return this.d;
        }
        set e(a) {
            this.d = a;
        }
        get i() {
            return this.h;
        }
        set i(a) {
            let b = this.h;
            this.h = a;
            if (this.h != b) {
                this.u("Height", b, this.h);
            }
        }
        get ac() {
            return this.ab;
        }
        set ac(a) {
            let b = this.ab;
            this.ab = a;
            if (this.ab != b) {
                this.u("Padding", b, this.ab);
            }
        }
        get y() {
            return this.w;
        }
        set y(a) {
            let b = this.w;
            this.w = a;
            if (this.w != b) {
                this.u("Background", b, this.w);
            }
        }
        get z() {
            return this.x;
        }
        set z(a) {
            let b = this.x;
            this.x = a;
            if (this.x != b) {
                this.u("TextColor", b, this.x);
            }
        }
        get p() {
            return this.k;
        }
        set p(a) {
            let b = this.k;
            this.k = a;
            if (this.k != b) {
                this.u("Text", b, this.k);
            }
        }
        get b() {
            return this.a;
        }
        set b(a) {
            let b = this.a;
            this.a = a;
            if (this.a != b) {
                this.u("FontInfo", b, this.a);
            }
        }
        constructor(a) {
            super();
            this.j = null;
            this.f = null;
            this.d = null;
            this.h = DeviceUtils.g(42);
            this.ab = new Thickness(1, 20, 0, 20, 0);
            this.w = BrushUtil.h(255, 237, 239, 245);
            this.x = BrushUtil.h(255, 0, 0, 0);
            this.k = "";
            this.a = TooltipTextPresenter.c();
            this.g = NaN;
            this.propertyChanged = null;
            this.j = a;
        }
        t(a) {
            NativeUIComponent.at(this.j, [7, 3], (b) => {
                this.e = b[0];
                this.e.be = this.ac;
                this.e.x = this.i;
                this.e.a4 = this.y;
                this.e.am = this;
                this.f = b[1];
                this.f.f = 1;
                this.f.h = 1;
                this.f.bh = false;
                this.f.bi = this.p;
                this.f.a6 = this.z;
                this.f.bg = this.b;
                this.e.bj(this.f);
                if (a != null) {
                    a();
                }
            });
        }
        aa() {
            if (isNaN_(this.g)) {
                let a = (document.createElement("canvas"));
                let b = a.getContext("2d");
                b.font = this.b.fontString;
                let c = b.measureText(this.p);
                this.g = c.width;
            }
            return new Size(1, this.ac.left + this.ac.right + this.g, this.ac.top + this.ac.bottom + this.i);
        }
        static c() {
            return ((() => {
                let $ret = new FontInfo();
                $ret.q = "Verdana";
                $ret.f = 14;
                $ret.t = "Normal";
                $ret.v = "Normal";
                $ret.r = "Normal";
                return $ret;
            })());
        }
        s() {
            if (this.e != null) {
                this.e.be = this.ac;
                this.e.x = this.i;
                this.e.a4 = this.y;
            }
            if (this.f != null) {
                this.f.bi = this.p;
                this.f.a6 = this.z;
                this.f.bg = this.b;
            }
        }
        u(a, b, c) {
            if (this.propertyChanged != null) {
                this.propertyChanged(this, new PropertyChangedEventArgs(a));
            }
            this.v(a, b, c);
        }
        v(a, b, c) {
            switch (a) {
                case "Background":
                case "Padding":
                case "Height":
                case "FontInfo":
                case "TextColor":
                    this.s();
                    break;
                case "Text":
                    this.g = NaN;
                    this.s();
                    break;
            }
        }
    }
    TooltipTextPresenter.$t = /*@__PURE__*/ markType(TooltipTextPresenter, 'TooltipTextPresenter', Base.$, [INotifyPropertyChanged_$type]);
    return TooltipTextPresenter;
})();

==> igniteui-react-layouts-18.7.3.tgz: package/esm2015/lib/TooltipTextPresenter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, INotifyPropertyChanged_$type, PropertyChangedEventArgs, markType } from "igniteui-react-core";
import { Thickness } from "igniteui-react-core";
import { FontInfo } from "igniteui-react-core";
import { DeviceUtils } from "igniteui-react-core";
import { BrushUtil } from "igniteui-react-core";
import { NativeUIComponent } from "igniteui-react-core";
import { Size } from "igniteui-react-core";
import { isNaN_ } from "igniteui-react-core";
/**
 * @hidden
 */
export let TooltipTextPresenter = /*@__PURE__*/ (() => {
    class TooltipTextPresenter extends Base {
        get e() {
            return this.d;
        }
        set e(a) {
            this.d = a;
        }
        get i() {
            return this.h;
        }
        set i(a) {
            let b = this.h;
            this.h = a;
            if (this.h != b) {
                this.u("Height", b, this.h);
            }
        }
        get ac() {
            return this.ab;
        }
        set ac(a) {
            let b = this.ab;
            this.ab = a;
            if (this.ab != b) {
                this.u("Padding", b, this.ab);
            }
        }
        get y() {
            return this.w;
        }
        set y(a) {
            let b = this.w;
            this.w = a;
            if (this.w != b) {
                this.u("Background", b, this.w);
            }
        }
        get z() {
            return this.x;
        }
        set z(a) {
            let b = this.x;
            this.x = a;
            if (this.x != b) {
                this.u("TextColor", b, this.x);
            }
        }
        get p() {
            return this.k;
        }
        set p(a) {
            let b = this.k;
            this.k = a;
            if (this.k != b) {
                this.u("Text", b, this.k);
            }
        }
        get b() {
            return this.a;
        }
        set b(a) {
            let b = this.a;
            this.a = a;
            if (this.a != b) {
                this.u("FontInfo", b, this.a);
            }
        }
        constructor(a) {
            super();
            this.j = null;
            this.f = null;
            this.d = null;
            this.h = DeviceUtils.g(42);
            this.ab = new Thickness(1, 20, 0, 20, 0);
            this.w = BrushUtil.h(255, 237, 239, 245);
            this.x = BrushUtil.h(255, 0, 0, 0);
            this.k = "";
            this.a = TooltipTextPresenter.c();
            this.g = NaN;
            this.propertyChanged = null;
            this.j = a;
        }
        t(a) {
            NativeUIComponent.av(this.j, [7, 3], (b) => {
                this.e = b[0];
                this.e.bg = this.ac;
                this.e.y = this.i;
                this.e.a6 = this.y;
                this.e.ao = this;
                this.f = b[1];
                this.f.f = 1;
                this.f.h = 1;
                this.f.bj = false;
                this.f.bk = this.p;
                this.f.a8 = this.z;
                this.f.bi = this.b;
                this.e.bl(this.f);
                if (a != null) {
                    a();
                }
            });
        }
        aa() {
            if (isNaN_(this.g)) {
                let a = (document.createElement("canvas"));
                let b = a.getContext("2d");
                b.font = this.b.fontString;
                let c = b.measureText(this.p);
                this.g = c.width;
            }
            return new Size(1, this.ac.left + this.ac.right + this.g, this.ac.top + this.ac.bottom + this.i);
        }
        static c() {
            return ((() => {
                let $ret = new FontInfo();
                $ret.q = "Verdana";
                $ret.f = 14;
                $ret.t = "Normal";
                $ret.v = "Normal";
                $ret.r = "Normal";
                return $ret;
            })());
        }
        s() {
            if (this.e != null) {
                this.e.bg = this.ac;
                this.e.y = this.i;
                this.e.a6 = this.y;
            }
            if (this.f != null) {
                this.f.bk = this.p;
                this.f.a8 = this.z;
                this.f.bi = this.b;
            }
        }
        u(a, b, c) {
            if (this.propertyChanged != null) {
                this.propertyChanged(this, new PropertyChangedEventArgs(a));
            }
            this.v(a, b, c);
        }
        v(a, b, c) {
            switch (a) {
                case "Background":
                case "Padding":
                case "Height":
                case "FontInfo":
                case "TextColor":
                    this.s();
                    break;
                case "Text":
                    this.g = NaN;
                    this.s();
                    break;
            }
        }
    }
    TooltipTextPresenter.$t = /*@__PURE__*/ markType(TooltipTextPresenter, 'TooltipTextPresenter', Base.$, [INotifyPropertyChanged_$type]);
    return TooltipTextPresenter;
})();
